---
title: Contextual save bar
description: The contextual save bar tells merchants their options once they have made changes to a form on the page. This component is also shown while creating a new object like a product or customer. Merchants can use this component to save or discard their work.
category: Forms
keywords:
  - form
  - forms
  - action
  - actions
  - save
  - cancel
  - logo
examples:
  - fileName: contextual-save-bar-default.tsx
    title: Default
    description: Use the save action to provide an opportunity to save changes. Use the discard action to allow merchants the option to discard their changes. Use the message to provide helpful context on the nature of those changes.
  - fileName: contextual-save-bar-with-flush-contents.tsx
    title: With flush contents
    description: Use the alignContentFlush flag when you want to omit the logo from the contextual save bar and repurpose that space to extend the message contents fully to the left side of the container.
  - fileName: contextual-save-bar-with-full-width.tsx
    title: With full width
    description: Use the fullWidth flag when you want to remove the default max-width set on the contextual save bar.
---

## Required components

The contextual save bar component must be wrapped in the [frame](https://polaris.shopify.com/components/frame) component.

---

## Best practices

The contextual save bar component should:

- Become visible when a form on the page has unsaved changes
- Be used to save or discard in-progress changes
- Provide brief and helpful context on the nature of in-progress changes
- Save all changes on the page. Avoid scenarios where multiple forms on a single page can be edited at the same time. If specific sections of a page need to be independently editable, use an Edit button to launch a [modal dialog](https://polaris.shopify.com/components/modal) for each section where changes can be made and saved.

---

## Content guidelines

Messages in the contextual save bar component should be informative, clear, and concise. They should follow the {adjective}+{noun} pattern. Don’t use full sentences.

The standard message content is

- “Unsaved changes” when editing existing content
- “Unsaved {resource name}” when creating a new object

<!-- dodont -->

#### Do

- Unsaved changes
- Unsaved product

#### Don’t

- You have unsaved changes
- Red and white striped shirt not yet saved

<!-- end -->

Actions in the contextual save bar component should consist of a strong verb that encourages action. They should not include a noun.

<!-- dodont -->

#### Do

- Save
- Discard

#### Don’t

- Save changes
- Discard changes

<!-- end -->

---

## Related components

- To wrap your entire application, [use the frame component](https://polaris.shopify.com/components/frame)
- To build the outer wrapper of a page, including page title and associated actions, [use the page component](https://polaris.shopify.com/components/page)
- To wrap form elements and handle the submission of a form, [use the form component](https://polaris.shopify.com/components/form)
