---
title: Layout
description: The layout component is used to create the main layout on a page. Layouts sections come in three main configurations. one-column, two-column, and annotated. One and two column layouts can be combined in the same page. Annotated layouts should be used on their own and only on settings pages.
category: Structure
keywords:
  - one column
  - two column
  - three column
  - column
  - annotated
  - page
  - column layouts
  - containers
  - full width containers
  - secondary sections
  - setting page
  - grouped sections
  - annotated sections
examples:
  - fileName: layout-one-column.tsx
    title: One-column
    description: Use to have a single section on its own in a full-width container. Use for simple pages and as a container for banners and other full-width content.
  - fileName: layout-two-columns-with-primary-and-secondary-widths.tsx
    title: Two columns with primary and secondary widths
    description: Use to follow a normal section with a secondary section to create a 2/3 + 1/3 layout on detail pages (such as individual product or order pages). Can also be used on any page that needs to structure a lot of content. This layout stacks the columns on small screens.
  - fileName: layout-two-columns-with-equal-width.tsx
    title: Two columns with equal width
    description: Use to create a ½ + ½ layout. Can be used to display content of equal importance. This layout will stack the columns on small screens.
  - fileName: layout-three-columns-with-equal-width.tsx
    title: Three columns with equal width
    description: Use to create a ⅓ + ⅓ + ⅓ layout. Can be used to display content of equal importance. This layout will stack the columns on small screens.
  - fileName: layout-annotated.tsx
    title: Annotated
    description: Use for settings pages. When settings are grouped thematically in annotated sections, the title and description on each section helps merchants quickly find the setting they’re looking for.
  - fileName: layout-annotated-with-sections.tsx
    title: Annotated with sections
    description: Use for settings pages. When settings are grouped thematically in annotated sections, the title and description on each section helps merchants quickly find the setting they’re looking for.
  - fileName: layout-annotated-with-banner-at-the-top.tsx
    title: Annotated with Banner at the top
    description: Use for settings pages that need a banner or other content at the top.
---

## Best practices

The layout component should:

- Use sections with white backgrounds for primary content and sections with grey backgrounds for secondary content that is less important
- Center cards on the background when there is no secondary card on the page to stop the content from becoming too wide
- Group similar concepts and actions together in cards
- Separate different cards using a full-width divider
- Structure primary/secondary, two-column layouts so the primary ⅔ section is used for main information and the secondary ⅓ section is used for information that might not be used as often but remains helpful for context or secondary tasks
- Use equal-width layouts with two or more columns when each layout section has the same importance

---

## Content guidelines

The content that appears in the layout component comes from cards and annotated sections.

### Cards

Content from cards should follow the content guidelines for [cards](https://polaris.shopify.com/components/card#content-guidelines).

### Annotated section titles

Annotated section titles should follow the content guidelines for [headings and subheadings](https://polaris.shopify.com/content/actionable-language#headings-and-subheadings).

### Annotated section descriptions

Annotated section descriptions should:

- Be used if the explanation or purpose of the associated cards isn’t clear
- Provide instructions for any choices merchants need to make, or explain the purpose of the section
- Be short, no more than 1–3 sentences
- Direct merchants to more content in the Help Center with “Learn more” links
- Not repeat the section title
- Use complete sentences and regular punctuation

---

## Related components

- To visually group content in a layout section, [use the card component](https://polaris.shopify.com/components/card)
- To lay out a set of smaller components in a row, [use the stack component](https://polaris.shopify.com/components/stack)
- To lay out form fields, [use the form layout component](https://polaris.shopify.com/components/form-layout)
