---
title: Naming
description: The names we give our products and features teach merchants how to use Shopify and how to find the things they need to run their business.
icon: ProductsMajor
keywords:
  - names
  - caps
  - capitalizations
  - capitalizing
  - how to name
  - naming at Shopify
  - naming guidelines
  - picking a name
  - product naming
  - feature naming
  - website naming
  - event naming
  - trademarked names
  - trademarks
  - branded names
  - capitalized names
  - abbreviation
  - acronym
---

## Thoughtful naming

Names influence how merchants and other audiences perceive and understand
Shopify. A well-chosen name will:

- Put clarity above creativity
- Help establish a mental model for our audiences
- Enhance people’s perception of our brand
- Increase adoption of the product or feature
- Differentiate Shopify from other products
- Clarify where a product or feature fits into our brand system

The naming process involves collaboration. Include different disciplines and people with different subject matter expertise in the creation of a name.

---

## Does it need a branded name?

Most features don’t need an official, branded name. For example, order entry is
a feature that’s referred to descriptively and so doesn’t need to be capitalized. When choosing what to call a feature, pick words that describe what the feature does or represents. If there’s room, add extra context for merchants by describing the feature instead of using only the feature name.

Avoid capitalizing descriptive feature names.

<!-- dodont -->

#### Do

- Order entry

#### Don’t

- Order Entry

<!-- end -->

If there‘s room, describe the feature instead of defaulting to only using the name.

<!-- dodont -->

#### Do

- Display carrier calculated shipping rates to your customers at checkout.

#### Don’t

- Display carrier calculated shipping rates.

<!-- end -->

### Using “Shopify”

Only Shopify can use the word “Shopify” in a name. The word “Shopify” can’t be used to name third-party products.

It’s important we use the word “Shopify” consistently, and sparingly. Don’t use
“Shopify” in a name unless there’s a lack of surrounding context and we want its target audience to know it’s associated with Shopify.

Adding “Shopify” doesn’t add clarity in the context of other Shopify products and features. For example, merchants often confuse Shopify Shipping with the other shipping features, like shipping settings, carrier calculated shipping rates, shipping labels, and shipping zones. Our support staff have to refer to the Shopify Plan by its cost because the general name doesn’t distinguish it from the other plans.

Use “Shopify” in front of a name when a product:

- Is or will become a separate product or platform and we need to associate it with Shopify
- Should be differentiated from other, similar products in the industry
- Doesn’t justify an [evocative name](/content/naming#descriptive-vs-evocative-names), but still needs to associated with Shopify

Don’t use “Shopify” in a name for built in functionality features, like fraud analysis or importing products.

<!-- dodont -->

#### Do

- Shopify Payments
- Shopify App Store
- Shopify Theme Store

#### Don’t

- Shopify Analytics
- Shopify Discounts
- Shopify Account

<!-- end -->

Shopify makes apps that merchants can add to their Shopify admin. It’s okay to say “Built by Shopify” or “Made by Shopify” after the app name. Once you’ve picked the format that works for the design, use it consistently.

<!-- dodont -->

#### Do

- _Shopify_ Product Reviews
- _Shopify_ Order Printer
- _Shopify_ Shopcodes

#### Don’t

- Product Reviews
- Order Printer
- Shopcodes

<!-- end -->

Apps that aren’t built by Shopify should not use the word “Shopify” in their name or say “for Shopify” after the name.

<!-- dodont -->

#### Do

- AdSpace
- Email Marketing

#### Don’t

- AdSpace for Shopify
- Email Marketing for Shopify

<!-- end -->

---

## Descriptive vs evocative names

There are two types of approaches to naming, the descriptive approach, or the evocative approach. Descriptive names are concrete, while evocative can be more abstract. Descriptive names are merchant friendly, and the most common. Features should always have descriptive names. Standalone products that require independent branding can use evocative names. Third-party apps and channels should have their own branded names and should never use the word “Shopify” in the name.

If you’re a Shopify employee and are looking to trademark an evocative name, ask the legal department for help.

### Descriptive names

Features and products connected to Shopify’s main product offering should have names that reveal something about their purpose. Avoid jargon and make sure the name you pick won’t get confused with similar names or terms.

Reserve evocative naming conventions for standalone products like Kit, and Frenzy.

Descriptive names should:

- Describe the experiences they represent
- Fit into the information architecture of the product
- Use merchant-friendly terms, not industry standard terms
- Make sense in marketing materials
- Align with brand

If it’s a default feature (merchants don’t have to sign up or opt in to use it), don’t [capitalize](/content/naming#general-guidelines) it.

<!-- dodont -->

#### Do

- Shopify Capital
- fraud analysis
- Use analytics to review your store’s transactions

#### Don’t

- Shopify capital
- Fraud Analysis
- Use Analytics to review your store’s transactions

<!-- end -->

Avoid jargon and give merchants a hint about the actions they’ll be able to take when they interact with the product or feature.

<!-- dodont -->

#### Do

- Shopify Help Center
- Shopify Theme Store
- discounts
- Logo maker

#### Don’t

- Shopify Help Documentation
- Configuration app
- Shipity-do-dah

<!-- end -->

### Evocative names

Standalone products use evocative names to position us in the industry. These unique and bold naming conventions can help with branding or recall, but don’t always help people understand the experience. They’re better for standalone products, and not for experiences that are part of Shopify’s main product offering.

Sometimes Shopify acquires a product or service that already has a unique, branded name. Even though it may become more tied to Shopify, it can keep its name to maintain its brand identity. This also helps maintain the context audiences already have about the product, like in the case of Kit.

Certain standalone names use the word “Shopify” because it differentiates the product from similar ones in the industry, like Shopify Pay in comparison to
Apple Pay, or Android Pay. For more details, see the
[guidelines for using “Shopify” in a name](/content/naming#does-it-need-a-branded-name-).

Evocative names should:

- Have a strong, independent brand identity
- Help with branding or recall
- Reflect the concept it represents
- Make sense when used in marketing materials

If you work at Shopify and want to trademark a name, talk to the legal department. It’s easier to trademark unique or made-up name. These names have stronger identities, but it’s not always clear what they do.

<!-- dodont -->

#### Do

- Frenzy
- Kit
- Oberlo

#### Don’t

- Flash sales app
- The Marketing Bot
- Drop Shipping app

<!-- end -->

Some evocative names can be more descriptive, although they’re harder to trademark if they use common terminology. Not all evocative names need to be trademarked.

<!-- dodont -->

#### Do

- Burst
- Shop Class

#### Don’t

- Free Stock Photography
- Learn about Shopify event

<!-- end -->

If you’re creating a website or product for an existing brand, maintain its brand identity and keep “Shopify” out of the name.

<!-- dodont -->

#### Do

- Kylie Jenner Pop-up Shop
- Kylie _Powered by Shopify_

#### Don’t

- Shopify Pop-up, featuring Kylie Jenner

<!-- end -->

---

## Shopify products and features

An off-brand and unclear name can confuse your audience. It can also feel disconnected from the rest of Shopify.

A good product or feature name should:

- Help merchants understand what the experience represents
- Fit into the information architecture of the product or website in which it belongs
- Make sense when compared to other products, features, websites, or events in the same market
- Avoid any negative or weird connotations

There are two types of approaches to naming, the
[descriptive approach, or the evocative approach](/content/naming#descriptive-vs-evocative-names).

### Referring to Shopify and areas in the admin

Use consistent and easy to understand descriptions when referring to locations in product, especially in [help documentation](/content/help-documentation#navigation). Descriptive feature names aren’t [capitalized](/content/naming#general-guidelines), but when providing steps in a workflow, it’s okay to capitalize the page name, for example, “Go to the Products page”. Note that the page name is capitalized, but “page” isn’t.

When referring to Shopify’s main product offering, use “Shopify”. The only exception is when you need to differentiate it from another product, like the mobile app, or explain a task specific to the admin. In these cases, you can use “Shopify admin”.

A good description can:

- Help establish a mental model for merchants
- Clarify where the area fits into the product system
- Help support staff and merchants understand each other when communicating

A good description should:

- Avoid jargon
- Be used consistently
- Describe the area it represents
- Prioritize terminology used by merchants over industry standards

Use consistent descriptions when referring to areas in the Shopify admin.

<!-- dodont -->

#### Do

- The customer list is found on the Customers page.
- When a new customer places an order with your store, their name and information are automatically added to your customer list.

#### Don’t

- Manage customers in Customers.
- Customer information is automatically added to Customers in the Shopify admin.

<!-- end -->

Merchants call our main product offering “Shopify”, so we use that same terminology. terminology

<!-- dodont -->

#### Do

- Use “Shopify” when talking about our main product offering
- Use “Shopify admin” if you need to differentiate it from the mobile app

#### Don’t

- Don’t use “admin” or “Shopify admin” if “Shopify” will do

<!-- end -->

Top-level marketing content is created for audiences who have little context about Shopify. Since they may not know about specific Shopify products, we use
“Shopify” here too.

<!-- dodont -->

#### Do

- Run your business using Shopify
- Print shipping labels directly through Shopify

#### Don’t

- Use our ecommerce platform
- Print shipping labels directly through Shopify’s admin

<!-- end -->

### Using “app” and “channel”

For app names in areas with surrounding context, like in the app store or on the
Apps page in the Shopify admin, don’t add the word “app” to the end of the name.

<!-- dodont -->

#### Do

- Oberlo
- Script Editor

#### Don’t

- Oberlo app
- Script Editor app

<!-- end -->

For app names without surrounding context, like in search in the Shopify admin, or on a home card, add “app” so merchants know what it is.

<!-- dodont -->

#### Do

- Bulk Account Order app

#### Don’t

- Bulk Account Order

<!-- end -->

When writing about channels, make it clear to merchants that they are interacting with
a channel through Shopify, and not through the other company.

<!-- dodont -->

#### Do

- The Amazon channel now supports electronics listings

#### Don’t

- Amazon now supports electronics listings

<!-- end -->

If “channel” is used somewhere in surrounding content, it’s okay to drop it for titles and button copy. titles

<!-- dodont -->

#### Do

- Add Amazon

#### Don’t

- Add Amazon channel

<!-- end -->

Not every channel is a sales channel. For example, BuzzFeed is a marketing outreach channel and Facebook is a sales and marketing channel. Clarify channel types when you have room, otherwise default to channel. If there’s surrounding context, you can drop channel altogether.

If there’s surrounding context, drop the word channel from the name.

<!-- dodont -->

#### Do

- Google Shopping

#### Don’t

- Google Shopping channel

<!-- end -->

If there’s room for a description, explain the channel type.

<!-- dodont -->

#### Do

- Use BuzzFeed’s marketing outreach channel to get more customers.

#### Don’t

- Use the BuzzFeed channel to get more customers.

<!-- end -->

---

## General guidelines

In general, capitalize evocative names and don’t capitalize feature names. Avoid acronyms, and think about how your audience will interpret a name.

### Capitalization

Don’t capitalize default features. Default features are built into Shopify and merchants don’t have to sign up, add, or opt in to use them. Analytics and discounts are examples of default features.

Capitalizing names should only happen:

- For independently branded,
  [evocative names](/content/naming#descriptive-vs-evocative-names)
- When we want to try and claim specific words (think Tweet or Pin)
- For names listed in top level navigation, like Products

<!-- dodont -->

#### Do

- Shopify Hardware Store
- Shopify Theme Store
- Black Friday Cyber Monday (BFCM)
- Retail Package
- Buy Button

#### Don’t

- Shopify hardware store
- Shopify theme store
- Black friday cyber monday (bfcm)
- Retail package
- Buy button

<!-- end -->

Names shouldn’t be capitalized if they:

- Are [descriptive](/content/naming#descriptive-vs-evocative-names)
- Include common, familiar words
- Are default features

<!-- dodont -->

#### Do

- analytics
- fraud analysis
- online store
- themes

#### Don’t

- Shopify Analytics
- Fraud Analysis
- Online Store
- Themes

<!-- end -->

### Acronyms and abbreviations

An acronym is a word formed from parts of an existing compound term. For example, “rich text editor” could be written as “RTE”. An abbreviation is a shortened form of a written word or phrase used in place of the whole word or phrase. “Amt” is an abbreviation for “amount”.

Our stance on acronyms:

- Avoid creating acronyms.
- Acronyms take longer to understand and might reduce adoption of a product, feature, or concept.
- Acronyms are like inside jokes—people who understand the acronym feel included in the meaning, but people who don’t feel left out and confused.
- If you have to use an acronym, spell it out the first time you use it and follow with the acronym in brackets.
- Internationally understood acronyms and abbreviations are acceptable, like the word “app” or “SEO”.

<!-- dodont -->

#### Do

- Rich text editor
- Multi label printing
- Merchant Success Manager
- Virtual reality
- Build a Bigger Business

#### Don’t

- RTE
- MLP
- MSM
- VR
- BABB

<!-- end -->

Avoid using Internet slang acronyms in Shopify products and when creating new, branded names. These acronyms are exclusive to certain online communities and branded approachable for everyday merchants.

<!-- dodont -->

#### Do

- Shop Class

#### Don’t

- Shopify IRL

<!-- end -->

Internationally understood acronyms and abbreviations are acceptable. Some of these include time zone, tax, barcode, weight, and size abbreviations.

<!-- dodont -->

#### Do

- SEO
- NZDT
- SMS
- QR codes
- HST
- CVV
- SKU
- ISBN
- UPC
- GTIN
- USD
- 1 kg
- 2 lbs
- App

#### Don’t

- Search engine optimization
- New Zealand Daylight Time
- Short messaging service
- Quick response codes
- Harmonized sales tax
- Card verification value
- Stock keeping unit
- International standard book number
- Universal product code
- Global trade item number
- United States Dollar
- Kilogram
- 2 pounds
- Application

<!-- end -->

When using a country as an adjective (such as when referring to currency), you may use an abbreviated form without punctuation.

<!-- dodont -->

#### Do

- Pinterest requires your store to use US currency.

#### Don’t

- Pinterest requires your store to use United States currency.

<!-- end -->

### Similar names

Being an ecommerce platform has its naming challenges. For example, a lot of feature names could include the word “shipping” or “pay”. Think merchant-first and be descriptive to differentiate the name. Picture what it’s like to have conversations with merchants about similar names like Shopify Payments and conversationsor around our pricing plans to identify names that might be confusing. confusingming a new product or feature:

- Conduct an audit of existing names to narrow down your naming choices
- Ask the support team to see if they think it’ll conflict with another name
- Draft a test conversation around similar sounding names

### Localization and translation

Names may not translate directly to other languages. Identify if you need to create a separate name, or if a direct translation will do.

Before confirming a name, check with people who work in translation and localization to find out if:

- There are cultural considerations
- A different name for a different location would have a positive impact for brand

Some already existing names are different depending where you’re from. For example, in North America, people say, “I’ll send you a text.” In India and Nordic countries, people say, “I’ll SMS you.” Do your research and find out what people call things in everyday conversations.

Use “text message” when writing for North American audiences.

<!-- dodont -->

#### Do

- text message

#### Don’t

- SMS

<!-- end -->

Use SMS when writing for Indian and Nordic audiences.

<!-- dodont -->

#### Do

- SMS

#### Don’t

- text message

<!-- end -->

### Initials

In languages that use logographic characters, like Japanese, name initials can have different meanings. For example, in Japanese a name like Chikako (周子) Ishikawa (石川) means “neighborhood stone” (周石) in initials. Check with the localization and translation team before writing something in short form in another language.

#### Avoiding negative connotations

Some words or terms have unintended negative connotations for some audiences. Do some research to avoid associating offensive words or phrases with your product or feature name.

Start by:

- Getting people outside of your team to look at the name with a new perspective
- Doing a Google search to see if it surfaces with another meaning

---

## Components

Be strategic and consistent when naming [components](/components). It makes it easier to create and build products and features for Shopify when people can switch between implementations and see the same names represented throughout. For example, we should use the same name across Rails, React, and Figma. It’s okay if each implementation has its own spelling convention. For example, “Account connection” in documentation and in Figma layer names, but “ui_account_connection” in Rails, and “AccountConnection” in React.

A good component name can:

- Increase adoption of a component
- Clarify where a component fits into our system
- Help establish a mental model for people using the components

Component names in documentation should:

- Describe the functionality they represent
- Avoid jargon so different disciplines understand its function
- Be written in singular, not plural, format

In documentation we write out the name without any punctuation and use sentence case, meaning, the first word is capitalized and the rest is lowercase.

<!-- dodont -->

#### Do

- Type scale
- Empty state

#### Don’t

- TypeScale
- EmptyState

<!-- end -->

In code, we use the same name as the documentation, but can alter the spelling convention to suit the implementation.

<!-- dodont -->

#### Do

- TypeScale
- EmptyState

#### Don’t

- Type scale
- Empty state

<!-- end -->

For subcomponents, the same rules apply. In documentation, write out the name with a space between words, and use sentence case. with

<!-- dodont -->

#### Do

- Layout section

#### Don’t

- Layout.Section

<!-- end -->

For subcomponents in the code, use a period in place of the space.

<!-- dodont -->

#### Do

- Layout.Section

#### Don’t

- Layout section

<!-- end -->

For all components, use American spelling:

<!-- dodont -->

#### Do

- Layout.Center
- Palette.Color

#### Don’t

- Layout.Centre
- Palette.Colour

<!-- end -->

There is an exception: the Labelled component uses the British spelling, following the `aria-labelledby` attribute as per the [ARIA specification](https://www.w3.org/TR/wai-aria-1.1/#aria-labelledby) itself.

---

## Icons

Icons should be named consistently so they’re easy to find and implement across
Shopify.

Overall, icon names should:

- Represent the intended function of the icon
- Avoid jargon so different disciplines understand its function

Product area icons should:

- Only be used to symbolize their specific product area or function

<!-- dodont -->

#### Do

- Home
- Orders
- Products

#### Don’t

- House
- Invoice
- Price tag

<!-- end -->

Functional icons not tied to product areas should represent a clear action.

<!-- dodont -->

#### Do

- Add image

#### Don’t

- Image

<!-- end -->

Icons with more than one function should be named to:

- Represent their purpose
- Describe how they look

<!-- dodont -->

#### Do

- Circle alert
- Camera
- Clock

#### Don’t

- Alert
- Photography
- Time

<!-- end -->
